@@ -15,7 +15,7 @@ extern "C" {
 enum {
   MAILIMAP_UIDPLUS_RESP_CODE_APND,
   MAILIMAP_UIDPLUS_RESP_CODE_COPY,
-  MAILIMAP_UIDPLUS_RESP_CODE_UIDNOTSTICKY,
+  MAILIMAP_UIDPLUS_RESP_CODE_UIDNOTSTICKY
 };
 
 struct mailimap_uidplus_resp_code_apnd {
